@@ -1,3 +1,6 @@
 from os.path import dirname, abspath
 
-ROOT_DIR = dirname(abspath(__file__))
\ No newline at end of file
+ROOT_DIR = dirname(abspath(__file__))
+
+__version__ = "1.0.3"
+__author__ = 'Moxie'
\ No newline at end of file
